# ttmask

[![License](https://img.shields.io/pypi/l/ttmask.svg?color=green)](https://github.com/teamtomo/ttmask/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/ttmask.svg?color=green)](https://pypi.org/project/ttmask)
[![Python Version](https://img.shields.io/pypi/pyversions/ttmask.svg?color=green)](https://python.org)
[![CI](https://github.com/teamtomo/ttmask/actions/workflows/ci.yml/badge.svg)](https://github.com/teamtomo/ttmask/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/teamtomo/ttmask/branch/main/graph/badge.svg)](https://codecov.io/gh/teamtomo/ttmask)

CLI tool for mask creation in cryo-EM/ET
